#[repr(u8)]pub enum ScheduleProgrammingVisibility {
Scheduleprogrammingpermitted = 0,
Scheduleprogrammingdenied = 1,
}Variants
Scheduleprogrammingpermitted = 0
Local schedule programming functionality is enabled at the thermostat
Scheduleprogrammingdenied = 1
Local schedule programming functionality is disabled at the thermostat
Implementations